---
feature_story: FS_13_51_07_97
feature_title: singled out implicit values
feature_status: TEST
---

When `FuncTreeInterp` interrogates user for `data_envelope` it should skip those arg types,
which are already singled out within current `args_context` (and can be implied as `ArgSource.ImplicitValue`).

Initial idea / example:
When `data_envelope` of `ServiceEnvelopeClass.ClassCluster` is found,
it has its arg types with assigned arg values ("coordinates"):
*   `code_maturity`
*   `flow_stage`
*   `geo_region`
*   `cluster_name`

This feature `FS_13_51_07_97` to assign singled out values from search results for the current `data_envelope`:

There is no point to interrogate arg type if it already has arg value singled out by
currently found `data_envelope` set (all `data_envelope`-s in the set have the same arg value for that arg type).

All arg types in `args_context` which have its values singled out
should be marked with `ArgSource.ImplicitValue` for current `data_envelope`.
